@@ -410,6 +410,59 @@ class CheckIdCardInformationResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class CheckPhoneAndNameRequest(AbstractModel):
+    """CheckPhoneAndName请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Mobile: ⼿机号
+        :type Mobile: str
+        :param Name: 姓名
+        :type Name: str
+        """
+        self.Mobile = None
+        self.Name = None
+
+
+    def _deserialize(self, params):
+        self.Mobile = params.get("Mobile")
+        self.Name = params.get("Name")
+
+
+class CheckPhoneAndNameResponse(AbstractModel):
+    """CheckPhoneAndName返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Result: 认证结果码，收费情况如下。
+收费结果码：
+0: 验证结果一致
+1: 验证结果不一致
+不收费结果码：
+-1:查无记录
+-2:引擎未知错误
+-3:引擎服务异常
+        :type Result: str
+        :param Description: 业务结果描述
+        :type Description: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Result = None
+        self.Description = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.Result = params.get("Result")
+        self.Description = params.get("Description")
+        self.RequestId = params.get("RequestId")
+
+
 class DetectAuthRequest(AbstractModel):
     """DetectAuth请求参数结构体
 
@@ -522,6 +575,13 @@ class DetectDetail(AbstractModel):
         :param Comparemsg: 本次一比一结果描述。（仅描述用，文案更新时不会通知。）
 注意：此字段可能返回 null，表示取不到有效值。
         :type Comparemsg: str
+        :param CompareLibType: 比对库源类型。包括：
+公安商业库；
+业务方自有库（用户上传照片、客户的混合库、混合部署库）；
+二次验证库；
+人工审核库；
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CompareLibType: str
         """
         self.ReqTime = None
         self.Seq = None
@@ -535,6 +595,7 @@ class DetectDetail(AbstractModel):
         self.Livemsg = None
         self.Comparestatus = None
         self.Comparemsg = None
+        self.CompareLibType = None
 
 
     def _deserialize(self, params):
@@ -550,6 +611,7 @@ class DetectDetail(AbstractModel):
         self.Livemsg = params.get("Livemsg")
         self.Comparestatus = params.get("Comparestatus")
         self.Comparemsg = params.get("Comparemsg")
+        self.CompareLibType = params.get("CompareLibType")
 
 
 class DetectInfoBestFrame(AbstractModel):
@@ -683,6 +745,13 @@ class DetectInfoText(AbstractModel):
         :param Mobile: 手机号码。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Mobile: str
+        :param CompareLibType: 本次流程最终比对库源类型。包括：
+公安商业库；
+业务方自有库（用户上传照片、客户的混合库、混合部署库）；
+二次验证库；
+人工审核库；
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CompareLibType: str
         """
         self.ErrCode = None
         self.ErrMsg = None
@@ -705,6 +774,7 @@ class DetectInfoText(AbstractModel):
         self.Extra = None
         self.LivenessDetail = None
         self.Mobile = None
+        self.CompareLibType = None
 
 
     def _deserialize(self, params):
@@ -734,6 +804,7 @@ class DetectInfoText(AbstractModel):
                 obj._deserialize(item)
                 self.LivenessDetail.append(obj)
         self.Mobile = params.get("Mobile")
+        self.CompareLibType = params.get("CompareLibType")
 
 
 class DetectInfoVideoData(AbstractModel):
@@ -1135,6 +1206,102 @@ class GetLiveCodeResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class GetRealNameAuthResultRequest(AbstractModel):
+    """GetRealNameAuthResult请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param AuthToken: 实名认证凭证
+        :type AuthToken: str
+        """
+        self.AuthToken = None
+
+
+    def _deserialize(self, params):
+        self.AuthToken = params.get("AuthToken")
+
+
+class GetRealNameAuthResultResponse(AbstractModel):
+    """GetRealNameAuthResult返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ResultType: 认证结果码，收费情况如下：
+
+收费码：
+0:  姓名和身份证号一致
+-1: 姓名和身份证号不一致
+-2: 姓名和微信实名姓名不一致
+
+不收费码：
+-3: 微信号未实名
+        :type ResultType: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ResultType = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.ResultType = params.get("ResultType")
+        self.RequestId = params.get("RequestId")
+
+
+class GetRealNameAuthTokenRequest(AbstractModel):
+    """GetRealNameAuthToken请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Name: 姓名
+        :type Name: str
+        :param IDCard: 身份证号
+        :type IDCard: str
+        :param CallbackURL: 回调地址。实名认证完成后，将会重定向到这个地址通知认证发起方。仅支持http或https协议。
+        :type CallbackURL: str
+        """
+        self.Name = None
+        self.IDCard = None
+        self.CallbackURL = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.IDCard = params.get("IDCard")
+        self.CallbackURL = params.get("CallbackURL")
+
+
+class GetRealNameAuthTokenResponse(AbstractModel):
+    """GetRealNameAuthToken返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param AuthToken: 查询实名认证结果的唯一凭证
+        :type AuthToken: str
+        :param RedirectURL: 实名认证授权地址，认证发起方需要重定向到这个地址获取认证用户的授权，仅能在微信环境下打开。
+        :type RedirectURL: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.AuthToken = None
+        self.RedirectURL = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.AuthToken = params.get("AuthToken")
+        self.RedirectURL = params.get("RedirectURL")
+        self.RequestId = params.get("RequestId")
+
+
 class IdCardOCRVerificationRequest(AbstractModel):
     """IdCardOCRVerification请求参数结构体
 
